# pandoc_glossary_filter

## Usage

```md
<!-- GLOSSARY -->
{g:mylabel} <!-- Inserts a glossary entry with label `mylabel` -->
{G:mylabel} <!-- Inserts a glossary entry with label `mylabel` capitalizing the first letter -->
{gs:mylabel} <!-- Inserts a glossary entry with label `mylabel` using the plural form -->
{Gs:mylabel} <!-- Inserts a glossary entry with label `mylabel` capitalizing the first letter and using the plural form -->

<!-- ACRONYMS -->
{a:myacro} <!-- Insert an acronym with label `myacro` -->
```

## TODO

- Add support for a full glossary document containing all the defined entries
- Actually usable documentation
